@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.76 2009/07/11 03:16:30 guru Exp $
+ *	$Id: grdmask.c,v 1.78 2009/09/09 23:27:03 guru Exp $
  *
  *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -533,6 +533,8 @@ int main (int argc, char **argv)
 	GMT_free ((void *)x);
 	GMT_free ((void *)y);
 	GMT_free ((void *)P.coord);
+	GMT_free ((void *)P.min);
+	GMT_free ((void *)P.max);
 
 	Free_Grdmask_Ctrl (Ctrl);	/* Deallocate control structure */
 
