@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.161 2009/07/11 03:16:31 guru Exp $
+ *	$Id: psxyz.c,v 1.163 2009/09/20 01:28:27 guru Exp $
  *
  *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -319,7 +319,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t       triangle : diagonal square when centered, directed triangle otherwise.\n"); 
 		fprintf (stderr, "\t     offset = start plotting symbols when along-track distance equals offset [0].\n"); 
 		fprintf (stderr, "\t   Kustom: append <symbolname> immediately after 'k'; this will look for <symbolname>.def in\n");
-		fprintf (stderr, "\t     the current directory or in %s or in %s/custom.\n", GMT_USERDIR, GMT_SHAREDIR);
+		fprintf (stderr, "\t     the current directory, in $GMT_USERDIR, or in $GMT_SHAREDIR (in that order).\n");
 		GMT_list_custom_symbols ();
 		fprintf (stderr, "\t   Letter: append /<string> after symbol size, and optionally %%<font>\n");
 		fprintf (stderr, "\t   Quoted line: Give [d|f|n|l|x]<info>[:<labelinfo>]. z must be constant for each segment\n");
